try:
    import json
except ImportError:
    from django.utils import simplejson as json

from django.contrib import messages



class AjaxMessagesMiddleware(object):
    """
    Middleware to handle messages for AJAX requests.

    If the AJAX response is already JSON, add a "messages" key to it (or
    append to an existing "messages" key) a list of messages (each
    message is an object with "level", "message", and "tags" keys).

    If the AJAX response is currently html, turn it into JSON and stuff
    the HTML content into the "html" key, adding a "messages" key as
    well.

    If the AJAX response is neither json nor html, return it as-is (with
    no messages attached, and without iterating over messages).

    If the AJAX response has a status code other than 200, or has an attribute
    ``no_messages`` that is ``True``, it will not be modified (and messages
    will not be read).

    """
    def process_response(self, request, response):
        handle_response = (
            request.is_ajax() and
            response.status_code == 200 and
            not getattr(response, 'no_messages', False)
            )
        if handle_response:
            content_type = response['content-type'].split(";")[0]

            content = response.content.decode('utf-8')

            if content_type == "application/json":
                data = json.loads(content)
            elif content_type == "text/html":
                data = {"html": content}
            else:
                return response

            messagelist = data.setdefault("messages", [])

            for message in messages.get_messages(request):
                messagelist.append({
                    "level": message.level,
                    "message": message.message,
                    "tags": message.tags,
                })

            response.content = json.dumps(data)
            response["content-type"] = "application/json"
        return response



from os.path import join, dirname

from setuptools import setup

here = dirname(__file__)

long_description = (
    open(join(here, "README.rst")).read() + "\n\n" +
    open(join(here, "CHANGES.rst")).read()
    )

def get_version():
    fh = open(join(here, "django-messages-ui.jquery.json"))
    try:
        for line in fh.readlines():
            if line.startswith('  "version":'):
                return line.split(":")[1].strip().strip('",')
    finally:
        fh.close()

setup(
    name="django-messages-ui",
    version=get_version(),
    description="JS client-side messages plugin, with support for Django contrib.messages app",
    long_description=long_description,
    author="Jonny Gerig Meyer",
    author_email="jonny@oddbird.net",
    url="https://github.com/jgerigmeyer/jquery-django-messages-ui/",
    packages=["messages_ui"],
    package_data={
        "messages_ui": [
            "static/messages_ui/*.*",
            "templates/messages_ui/*.html",
            "jstemplates/*.html"
            ]
        },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Framework :: Django",
    ],
    zip_safe=False,
)
